CSS Integration JSON Editor Example

# Materialize CSS – JSON Editor Example

JSON Editor supports these popular CSS frameworks:

- Bootstrap 2
- Bootstrap 3
- Foundation 3
- Foundation 4
- Foundation 5
- jQuery UI
- Materialize (shown here, see http://materializecss.com/)

JSON Editor supports these popular icon libraries:

- Bootstrap 2 Glyphicons
- Bootstrap 3 Glyphicons
- Foundicons 2
- Foundicons 3
- jQueryUI
- Font Awesome 3
- Font Awesome 4
- Material Icons (shown here, see https://material.io/icons/)